function annotateUnitCell(X,Y,ori,UnitCellType,ScaleFactor,LineWdth,LineColour,FillFace,FillColour)
%ANNOTATEUNITCELL draws a unit cell over an ebsd or grain map previously
%drawn.  Possible unit cells are HCP, cubic, and orthogonal axes.
%X and Y are the coordinates on the map to be used, ebsd is the orientation
%data for all points, UnitCellType is 1 for HCP, 2 for Cubic, 3 for
%orthogonal.  ScaleFactor >1 increases the size of the unit cell, while
%values <1 decrease it.  LineWdth,LineColour control the outline of the
%unit cell.  FillFace,FillColour control the filling of the faces of the
%unit cell (FillFace=1 is fill faces), and the colour of fill

% Part 1 create the basic unit cell
if UnitCellType==1
%since MTEX default is X along [10-10], picture hexagon with pointy end up
%(in y) length of vertex from center = 6 units.  Label vertexes A-F.  Top
%is upper vertexes, B is bottom vertexes

%clockwise from top.  Note that we use vector3d instead of standard arrays
%to allow use of euler rotation functions
vertexAT=vector3d(0,6,12);
vertexBT=vector3d(5.196,3,12);
vertexCT=vector3d(5.196,-3,12);
vertexDT=vector3d(0,-6,12);
vertexET=vector3d(-5.196,-3,12);
vertexFT=vector3d(-5.196,3,12);
vertexAB=vector3d(0,6,0);
vertexBB=vector3d(5.196,3,0);
vertexCB=vector3d(5.196,-3,0);
vertexDB=vector3d(0,-6,0);
vertexEB=vector3d(-5.196,-3,0);
vertexFB=vector3d(-5.196,3,0);
%combine in vertex array 
v=[vertexAT;vertexBT;vertexCT;vertexDT;vertexET;vertexFT;vertexAB;vertexBB;vertexCB;vertexDB;vertexEB;vertexFB];
%provide information on the order in which to connect faces of hex prism.
%Note, sides only.
f=[1 2 8 7;2 3 9 8;3 4 10 9;4 5 11 10;5 6 12 11;6 1 7 12];

elseif UnitCellType==2
 %this section if cube selected 
    %clockwise from top.  Note that we use vector3d instead of standard arrays
%to allow use of euler rotation functions
vertexAT=vector3d(12,0,12);
vertexBT=vector3d(0,0,12);
vertexCT=vector3d(0,12,12);
vertexDT=vector3d(12,12,12);
vertexAB=vector3d(12,0,0);
vertexBB=vector3d(0,0,0);
vertexCB=vector3d(0,12,0);
vertexDB=vector3d(12,12,0);

%combine in vertex array 
v=[vertexAT;vertexBT;vertexCT;vertexDT;vertexAB;vertexBB;vertexCB;vertexDB];
%provide information on the order in which to connect faces of cube.
%Note, first four sides only.
f=[1 2 6 5;2 3 7 6;3 4 8 7;4 1 5 8;1 2 3 4;5 6 7 8];

else %this one is for orthogonal axes
        %clockwise from top.  Note that we use vector3d instead of standard arrays
%to allow use of euler rotation functions
vertexX=vector3d(12,0,0);
vertexY=vector3d(0,12,0);
vertexZ=vector3d(0,0,12);
vertexO=vector3d(0,0,0);

%combine in vertex array 
v=[vertexO;vertexX;vertexY;vertexZ];
%provide 
%Note, f, providing information on the order in which to connect faces of cube.
%is down later in the plot section for this graph


%put special case here to flag orthogonal plot.
FillFace=3;
end

%part 2- rotate the unit cell and draw appropriately
hold on
for i=1:size(X,1)
    %if the xy coords selected have zero or more than one ebsd points
    %associated, skip
 
%enter rotation to transform the unit cell
o = rotation('Euler',ori(i).phi1,ori(i).Phi,ori(i).phi2);

%combine in vertex array and rotate
v_T3d=o*v;

%convert rotated vector3d back to matrix for plotting
if UnitCellType==1
%if HCP
    v_T=[v_T3d(1).x v_T3d(1).y v_T3d(1).z;v_T3d(2).x v_T3d(2).y v_T3d(2).z;v_T3d(3).x v_T3d(3).y v_T3d(3).z;v_T3d(4).x v_T3d(4).y v_T3d(4).z;v_T3d(5).x v_T3d(5).y v_T3d(5).z;v_T3d(6).x v_T3d(6).y v_T3d(6).z;v_T3d(7).x v_T3d(7).y v_T3d(7).z;v_T3d(8).x v_T3d(8).y v_T3d(8).z;v_T3d(9).x v_T3d(9).y v_T3d(9).z;v_T3d(10).x v_T3d(10).y v_T3d(10).z;v_T3d(11).x v_T3d(11).y v_T3d(11).z;v_T3d(12).x v_T3d(12).y v_T3d(12).z];
elseif UnitCellType==2 %if cube
    v_T=[v_T3d(1).x v_T3d(1).y v_T3d(1).z;v_T3d(2).x v_T3d(2).y v_T3d(2).z;v_T3d(3).x v_T3d(3).y v_T3d(3).z;v_T3d(4).x v_T3d(4).y v_T3d(4).z;v_T3d(5).x v_T3d(5).y v_T3d(5).z;v_T3d(6).x v_T3d(6).y v_T3d(6).z;v_T3d(7).x v_T3d(7).y v_T3d(7).z;v_T3d(8).x v_T3d(8).y v_T3d(8).z];
else %if orthogonal axes plot
    v_T=[v_T3d(1).x v_T3d(1).y v_T3d(1).z;v_T3d(2).x v_T3d(2).y v_T3d(2).z;v_T3d(3).x v_T3d(3).y v_T3d(3).z;v_T3d(4).x v_T3d(4).y v_T3d(4).z];
end


%scale v_T if required
v_T=v_T*ScaleFactor;
%check which way axes are positive

%move v_T to appropriate location
v_T(:,1)=v_T(:,1)+X(i);
v_T(:,2)=v_T(:,2)+Y(i);

%if z plot direction is into plane, Ensure v_T(z) is all <0 to ensure all 
%lines above ebsd map surface and visible
if strcmpi(getMTEXpref('zAxisDirection'),'intoPlane')
test1=max(v_T(:,3));
if test1>0
v_T(:,3)=v_T(:,3)-test1;
end

else %if z out of plane Ensure v_T(z) is all >0 to ensure all lines above 
    %ebsd map surface and visible
test1=min(v_T(:,3));
if test1<0
v_T(:,3)=v_T(:,3)-test1;
end
end

if FillFace==1
    %plot with filled faces
patch('Faces',f,'Vertices',v_T,'FaceColor',FillColour,'LineWidth',LineWdth,'Edgecolor',LineColour); % plotting the prism with face and vertex data

elseif FillFace==0%plot wireframe
patch('Faces',f,'Vertices',v_T,'FaceAlpha',0,'LineWidth',LineWdth,'Edgecolor',LineColour); 

else %special case for cartesian axes
f=[1 2];
patch('Faces',f,'Vertices',v_T,'FaceAlpha',0,'LineWidth',LineWdth,'Edgecolor','green'); 
f=[1 3];
patch('Faces',f,'Vertices',v_T,'FaceAlpha',0,'LineWidth',LineWdth,'Edgecolor','red'); 
f=[1 4];
patch('Faces',f,'Vertices',v_T,'FaceAlpha',0,'LineWidth',LineWdth,'Edgecolor','black'); 
end


end
hold off
end